/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// SWIG input file of the 'dart' module

%feature("autodoc","1");

%module(docstring=
"'dartw' module: full potential solver 2018-2021
(c) ULg - A&M",
directors="0",
threads="1"
) dartw
%{

#include "dart.h"

#include "fwkw.h"
#include "tboxw.h"
#include "dartw.h"

%}


%include "fwkw.swg"

// ----------- MODULES UTILISES ------------
%import "tboxw.i"

// ----------- FLOW CLASSES ----------------
%include "dart.h"

%shared_ptr(dart::Medium);
%shared_ptr(dart::Assign);
%shared_ptr(dart::Initial);
%shared_ptr(dart::Dirichlet);
%shared_ptr(dart::Freestream);
%shared_ptr(dart::Wake);
%shared_ptr(dart::Kutta);
%shared_ptr(dart::Blowing);
%shared_ptr(dart::Boundary);
%shared_ptr(dart::Problem);
%shared_ptr(dart::Solver);
%shared_ptr(dart::Picard);
%shared_ptr(dart::Newton);
%shared_ptr(dart::Adjoint);

%include "wMedium.h"
%include "wAssign.h"
%include "wFreestream.h"
%warnfilter(509); // Shadowed constructor. Code compiling and running.
%include "wWake.h"
%include "wKutta.h"
%include "wBoundary.h"
%include "wBlowing.h"
%warnfilter(+509);
%include "wWakeElement.h"
%include "wKuttaElement.h"

%immutable dart::Problem::msh; // read-only variable (no setter)
%include "wProblem.h"

%immutable dart::Solver::pbl;
%immutable dart::Solver::linsol; // read-only variable (no setter)
%include "wSolver.h"
%include "wPicard.h"
%include "wNewton.h"

%immutable dart::Adjoint::sol;
%immutable dart::Adjoint::def;
%immutable dart::Adjoint::linsol; // read-only variable (no setter)
%include "wAdjoint.h"
